@@ -26,8 +26,8 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.2.7"
-referer_list = ["https://www.google.com/", "https://www.youtube.com/", "https://www.twitter.com/", "https://www.discord.com/", "https://www.tiktok.com/", "https://www.instagram.com/"]
+version = "1.2.8"
+referer_list = ["https://www.google.com/", "https://www.youtube.com/", "https://www.twitter.com/", "https://www.discord.com/", "https://www.tiktok.com/", "https://www.instagram.com/", "https://check-host.net/", "https://github.com", "https://gitlab.com", "https://he1zen.rf.gd"]
 
 major = str(sys.version_info.major)
 minor = str(sys.version_info.minor)
@@ -296,19 +296,18 @@ class ip:
     def proxy(data=False):
         import requests
         if data:
-           proxy = []
-           proxy.append(proxis)
+           list = []
            proxy_list = pyproxify.fetch(count=7, google=True, https=True)
            for item in proxy_list:
                ip = item["ip"]
                port = item["port"]
-               proxy.append(ip+":"+port)
+               list.append(ip+":"+port)
            proxy_list = pyproxify.fetch(count=8, https=True)
            for item in proxy_list:
                ip = item["ip"]
                port = item["port"]
-               proxy.append(ip+":"+port)
-           return proxy
+               list.append(ip+":"+port)
+           return list
         else:
            done = False
            def animate():
